@@ -2,7 +2,7 @@ import os
 import sys
 import pprint
 
-import Image
+from PIL import Image
 
 from av import open
 
