@@ -1,3 +1,4 @@
+from __future__ import print_function
 from .common import *
 
 
@@ -16,21 +17,21 @@ class TestAudioFifo(TestCase):
         for i, packet in enumerate(container.demux(stream)):
             for frame in packet.decode():
                 
-                print '<<<', frame
+                print('<<<', frame)
                 
                 input_.append(frame.planes[0].to_bytes())
                 fifo.write(frame)
                 while frame:
                     frame = fifo.read(512)
                     if frame:
-                        print '>>>', frame
+                        print('>>>', frame)
                         output.append(frame.planes[0].to_bytes())
 
             if len(output) > 10:
                 break
 
-        input_ = ''.join(input_)
-        output = ''.join(output)
+        input_ = b''.join(input_)
+        output = b''.join(output)
         min_len = min(len(input_), len(output))
 
         self.assertTrue(min_len > 10 * 512 * 2 * 2)
