@@ -1,3 +1,4 @@
+from __future__ import print_function
 from .common import *
 
 
@@ -22,10 +23,10 @@ class TestDecode(TestCase):
         
         sample_count = 0
         
-        print audio_stream.frames
+        print(audio_stream.frames)
         for packet in container.demux(audio_stream):
             for frame in packet.decode():
                 sample_count += frame.samples
         
         total_samples = (audio_stream.duration * audio_stream.rate.numerator) / audio_stream.time_base.denominator
-        self.assertEqual(sample_count, total_samples)
\ No newline at end of file
+        self.assertEqual(sample_count, total_samples)
